from distutils.core import setup

setup(
    name = 'dis',
    version ='1.0.0',
    py_modules = ['nester'],
    author = 'sandy',
    author_email = 'sandyzhao@wisehandy.com',
    url = 'http://www.wisehandy.com',
    description = 'A simple test',
    )
